@@ -1,10 +1,11 @@
 var indexSectionsWithContent =
 {
-  0: "_abcdefghilmnoprstuvx~",
+  0: "_abcdefghilmnopqrstuvx~",
   1: "bceinrstvx",
-  2: "abcdefghilmnoprstuvx~",
-  3: "_dhiors",
-  4: "dr"
+  2: "abcdefghilmnopqrstuvx~",
+  3: "_dehimoqrs",
+  4: "mnv",
+  5: "dr"
 };
 
 var indexSectionNames =
@@ -13,7 +14,8 @@ var indexSectionNames =
   1: "classes",
   2: "functions",
   3: "variables",
-  4: "pages"
+  4: "typedefs",
+  5: "pages"
 };
 
 var indexSectionLabels =
@@ -22,6 +24,7 @@ var indexSectionLabels =
   1: "Classes",
   2: "Functions",
   3: "Variables",
-  4: "Pages"
+  4: "Typedefs",
+  5: "Pages"
 };
 
